"use strict";
const chalk = require('chalk');
const TAG_MAP = {
    b: chalk.bold,
    i: chalk.italic,
    u: chalk.underline,
    s: chalk.strikethrough,
    bold: chalk.bold,
    underline: chalk.underline,
    strikethrough: chalk.strikethrough,
    italic: chalk.italic,
    inverse: chalk.inverse,
    black: chalk.black,
    red: chalk.red,
    green: chalk.green,
    yellow: chalk.yellow,
    blue: chalk.blue,
    magenta: chalk.magenta,
    cyan: chalk.cyan,
    white: chalk.white,
    gray: chalk.gray,
    bgBlack: chalk.bgBlack,
    bgRed: chalk.bgRed,
    bgGreen: chalk.bgGreen,
    bgYellow: chalk.bgYellow,
    bgBlue: chalk.bgBlue,
    bgMagenta: chalk.bgMagenta,
    bgCyan: chalk.bgCyan,
    bgWhite: chalk.bgWhite
};
const TAG_REGEX = new RegExp('</?(' + Object.keys(TAG_MAP).join('|') + ')>', 'g');
TAG_MAP['root'] = (content) => content;
const isTag = (el) => el.type === 'tag';
const parse = (markup) => {
    let current = {
        type: 'tag',
        name: 'root',
        children: []
    };
    let stack = [current];
    let start = 0;
    markup.replace(TAG_REGEX, (tag, name, index) => {
        if (start < index) {
            current.children.push({
                type: 'text',
                content: markup.slice(start, index)
            });
        }
        start = index + tag.length;
        if (tag.charAt(1) !== '/') {
            current = {
                type: 'tag',
                name,
                children: []
            };
            stack[stack.length - 1].children.push(current);
            stack.push(current);
        }
        else {
            const matchingLevel = stack.map(tag => tag.name).lastIndexOf(name);
            if (matchingLevel !== -1) {
                stack = stack.slice(0, matchingLevel);
                current = stack[matchingLevel - 1];
            }
        }
        return '';
    });
    if (start < markup.length) {
        current.children.push({
            type: 'text',
            content: markup.slice(start)
        });
    }
    return stack[0];
};
let serialize = (tag) => {
    const format = TAG_MAP[tag.name];
    const content = tag.children.map((child) => {
        if (isTag(child)) {
            return serialize(child);
        }
        else {
            return child.content;
        }
    }).join('');
    return format ? format(content) : `<${tag.name}>${content}</${tag.name}>`;
};
module.exports = (markup) => serialize(parse(markup));
//# sourceMappingURL=index.js.map